
Changelog
=========

0.4.0 (2018-09-06)
------------------

* Single ended calibration
* Confidence intervals for single ended calibration
* Example notebooks have figures embedded
* Several bugs squashed
* Reorganized DataStore functions


0.2.0 (2018-08-16)
------------------

* Double ended calibration
* Confidence intervals for double ended calibration


0.1.0 (2018-08-01)
------------------

* First release on PyPI.
